@@ -1,5 +1,5 @@
 echo EXPORTS > qtbase.def
 nm -g --defined-only CMakeFiles/qtbase.dir/*.obj > tmp
-sed -n '/^........ [T|C|B] _/s/^........ [T|C|B] _/ /p' tmp >> qtbase.def
+sed -n $1 tmp >> qtbase.def
 rm tmp
 
